/*____________________________________________________________________________
	
	FreeAmp - The Free MP3 Player

	Portions Copyright (C) 1998-1999 EMusic.com

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
	
	$Id: mutex.h,v 1.5 1999/10/19 07:12:48 elrod Exp $
____________________________________________________________________________*/

#ifndef MUTEX_H
#define MUTEX_H

#include <windows.h>

#define WAIT_FOREVER INFINITE

class Mutex {

public:
	Mutex(bool createOwned = false);
	~Mutex();


	bool Acquire(unsigned long timeout = WAIT_FOREVER);
	void Release();


private:
	HANDLE m_mutex;	

};

#endif /* MUTEX_H */
